==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebPositionStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPositionSettingsDescriptionMetadata } from "./WebPositionSettingsDescriptionMetadata";
import { WebPositionStrategyDescription } from "./WebPositionStrategyDescription";
/**
 * @hidden
 */
var WebPositionStrategyDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPositionStrategyDescriptionMetadata, _super);
    function WebPositionStrategyDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPositionStrategyDescriptionMetadata.b = function (a) {
        if (WebPositionStrategyDescriptionMetadata.a == null) {
            WebPositionStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPositionStrategyDescriptionMetadata.c(WebPositionStrategyDescriptionMetadata.a);
        }
        if (a.j(WebPositionStrategyDescriptionMetadata.a)) {
            return;
        }
        a.y(WebPositionStrategyDescriptionMetadata.a);
        WebPositionSettingsDescriptionMetadata.d(a);
    };
    WebPositionStrategyDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PositionStrategy");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Settings", "ExportedType:WebPositionSettings");
    };
    WebPositionStrategyDescriptionMetadata.d = function (a) {
        WebPositionStrategyDescriptionMetadata.b(a);
        a.aa("WebPositionStrategy", function () { return new WebPositionStrategyDescription(); });
        a.z("WebPositionStrategy", WebPositionStrategyDescriptionMetadata.a);
    };
    WebPositionStrategyDescriptionMetadata.$t = markType(WebPositionStrategyDescriptionMetadata, 'WebPositionStrategyDescriptionMetadata');
    WebPositionStrategyDescriptionMetadata.a = null;
    return WebPositionStrategyDescriptionMetadata;
}(Base));
export { WebPositionStrategyDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebPositionStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPositionSettingsDescriptionMetadata } from "./WebPositionSettingsDescriptionMetadata";
import { WebPositionStrategyDescription } from "./WebPositionStrategyDescription";
/**
 * @hidden
 */
var WebPositionStrategyDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPositionStrategyDescriptionMetadata, _super);
    function WebPositionStrategyDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPositionStrategyDescriptionMetadata.b = function (a) {
        if (WebPositionStrategyDescriptionMetadata.a == null) {
            WebPositionStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPositionStrategyDescriptionMetadata.c(WebPositionStrategyDescriptionMetadata.a);
        }
        if (a.k(WebPositionStrategyDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebPositionStrategyDescriptionMetadata.a);
        WebPositionSettingsDescriptionMetadata.d(a);
    };
    WebPositionStrategyDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PositionStrategy");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Settings", "ExportedType:WebPositionSettings");
    };
    WebPositionStrategyDescriptionMetadata.d = function (a) {
        WebPositionStrategyDescriptionMetadata.b(a);
        a.ac("WebPositionStrategy", function () { return new WebPositionStrategyDescription(); });
        a.ab("WebPositionStrategy", WebPositionStrategyDescriptionMetadata.a);
    };
    WebPositionStrategyDescriptionMetadata.$t = markType(WebPositionStrategyDescriptionMetadata, 'WebPositionStrategyDescriptionMetadata');
    WebPositionStrategyDescriptionMetadata.a = null;
    return WebPositionStrategyDescriptionMetadata;
}(Base));
export { WebPositionStrategyDescriptionMetadata };
